import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import { useEvent, useMergedState } from 'rc-util';
import React from 'react';

// We need wait for outside state updated.
// Which means need 2 effect:
// 1. Outside sync state
// 2. Still may be old state
// 3. Safe to sync state
var DELAY_TIMES = 2;

/**
 * Will be `true` immediately for next effect.
 * But will be `false` for a delay of effect.
 */
export default function useDelayState(value, defaultValue, onChange) {
  var _useMergedState = useMergedState(defaultValue, {
      value: value
    }),
    _useMergedState2 = _slicedToArray(_useMergedState, 2),
    state = _useMergedState2[0],
    setState = _useMergedState2[1];
  var _React$useState = React.useState(false),
    _React$useState2 = _slicedToArray(_React$useState, 2),
    times = _React$useState2[0],
    setTimes = _React$useState2[1];
  var nextValueRef = React.useRef(value);

  // ============================= Update =============================
  var doUpdate = useEvent(function () {
    setState(nextValueRef.current);
    if (onChange && state !== nextValueRef.current) {
      onChange(nextValueRef.current);
    }
  });
  var updateValue = useEvent(function (next, immediately) {
    nextValueRef.current = next;
    if (next || immediately) {
      doUpdate();
      setTimes(false);
    } else {
      setTimes(0);
    }
  });

  // ============================= Effect =============================
  React.useEffect(function () {
    if (times === DELAY_TIMES) {
      doUpdate();
    } else if (times !== false && times < DELAY_TIMES) {
      setTimes(times + 1);
    }
  }, [times, doUpdate]);
  return [state, updateValue];
}